
# q-expansion of newform 531.4.a.h, downloaded from the LMFDB on 01 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 531
weight = 4
poly_data = [788240, -1588880, -1451104, 2749404, 170415, -1057340, 84830, 167704, -21599, -12642, 1897, 448, -72, -6, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-12, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[9, -20, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-269281139197813264, -138921273945620128, 169111063265628416, 95336564995817892, -24999982300830899, -21887373158774669, 2303181185544587, 2128449535468345, -79757646061942, -104066256844160, -3139116726585, 3089447119813, 160984518439, -48158651061], 8527798208321536], [[58194752986772720, -14734363723705248, -244220722733080192, 22134356016885092, 109501629966329085, -9059535399603853, -18609981214208005, 1695590458237145, 1467955847922538, -153301468691104, -54083762564681, 6385824890149, 752559234487, -98101980757], 4263899104160768], [[540133933836277744, 98673504819253088, -1002264759624177664, 83483827734418340, 333143154384334189, -53032832311641965, -44929816121335701, 9263176354099225, 2901292143593674, -682029546575488, -87366185855321, 22073922081317, 966986865415, -256455347477], 8527798208321536], [[-58082513629807536, 44167807783027744, 234083261744770176, -274130868628035700, -105103711812451265, 90953287678324929, 19974668362533385, -11536747193361501, -1932650780135986, 743911014358848, 90916480815581, -25417777875161, -1597744791555, 364244244041], 8527798208321536], [[59967029629067152, -40752783188699136, -139732038856968912, 72270454074390788, 54084380167815335, -24668235041945783, -7839658966377135, 3276637275093427, 508178017253118, -201437307405592, -14632562383275, 5696132108207, 147839605173, -59045299415], 1065974776040192], [[-247560100865676784, 451062736819284256, 317304664116421952, -387117761840966980, -120434772147009021, 103613174102485981, 21124843962416485, -12562941735926569, -1794387194091882, 776577736605728, 71397845487465, -24062040339989, -1064435458295, 297710377765], 4263899104160768], [[-105937421622737200, 91927330092555424, 198650046933591104, -88933693025098580, -86836833320798585, 30384049619282193, 15404207203912433, -4525728261861885, -1265229526356450, 327470852832304, 48177581284325, -11369416291705, -688610860235, 151911786665], 2131949552080384], [[86675307793904752, -28811428511985504, -238983055705405600, 109219538199038292, 121208394747289309, -42553194932252613, -23263868227020725, 6479901852700145, 1990585370112490, -473527436243648, -77121556088217, 16554284399053, 1105004461047, -222012754925], 2131949552080384], [[-51018851646835152, -520952390196490784, -292701811308196352, 727835619745540244, 281993686408038233, -259087066248601113, -66727905410103265, 37350303498399125, 6078687377243362, -2550108134703360, -233301488993685, 81637490506097, 3173060443211, -983252880673], 8527798208321536], [[-644785830658449200, 1220178327525816864, 1267832365389787904, -1569117486523253204, -566626887750836297, 483669428313389193, 102238914696796497, -62986278431954629, -8322468441547714, 4005084471264896, 305640253904837, -122383217750113, -4121584256027, 1435647457937], 8527798208321536]]

hecke_ring_character_values = None
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2, 0, -1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [-2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0], [-7, -2, -1, 0, 0, -1, 0, 0, 0, 1, -1, 1, 0, 0], [6, 3, 0, 0, -1, 0, -1, 0, 1, -1, 1, -1, 1, 0], [-12, 1, 0, 2, 0, -3, 0, 1, -1, -1, -1, 3, -2, 0], [-11, 3, 3, -2, -2, -2, -1, -4, 2, -1, 0, 0, 1, 2], [-28, 8, -1, 2, 7, -3, 3, 3, -4, 1, 0, 3, 0, -3], [-76, 5, -2, -2, -2, 0, 6, -5, 0, 0, 1, -2, 3, 2], [-12, 12, -2, -4, -1, 6, 3, 1, 0, -3, 4, -3, 4, -1], [-18, 16, -1, 0, 2, 1, -6, 0, -2, 3, 0, -1, -1, 0], [-66, 5, 14, -2, -5, 3, -4, 0, 4, -2, 4, 0, 1, 5], [12, 3, -3, -2, -8, -1, -1, -3, 2, -8, 0, 0, -4, 7], [-50, 22, 15, 2, 0, 0, 5, -2, -3, 1, 1, 5, 2, -7], [-100, -7, 19, -8, 1, 3, 2, -8, 2, -4, -8, -2, 5, 0], [59, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [30, -21, 8, 0, 20, -22, 7, 11, -14, 9, -12, 7, -3, -9], [48, 2, -8, 6, -19, 11, -9, 1, 5, 15, 8, -11, -8, 1], [-196, 25, 26, 2, 13, -5, -2, 16, 5, -3, 6, 9, 0, 4], [-80, -68, 25, -4, -24, -13, -21, -2, 15, 0, 3, -2, 11, 20], [-62, -81, 9, -4, 11, -16, -7, 1, -20, 0, 2, -1, -3, -4], [-328, -21, -12, -12, -40, 22, -7, -10, 8, -7, 11, -14, 16, 17], [-367, 27, 5, 6, -7, 14, -9, -3, 11, 16, 7, -23, -12, -3], [44, -160, 20, -4, 31, -57, -3, 1, -9, 19, -12, 3, -8, -5], [-380, -39, -49, 18, 26, -14, -18, 42, -21, 18, -18, -13, -26, -12], [-38, -19, 19, 12, 12, 27, 6, -3, 17, -15, 21, 7, 2, -9], [-230, -40, 13, 6, -9, -15, -18, 1, 16, 0, -7, 8, -22, -12], [88, -154, 40, 4, -2, -19, 6, -24, 7, -4, 10, 4, 6, -4], [-214, 8, 56, -4, 35, -31, 36, 21, -15, 18, 1, 8, -22, -12], [-40, -68, 2, 38, 11, 10, 21, -9, -5, -14, -6, 32, -5, -4], [-329, 51, 30, -2, -23, -12, 28, -33, 16, -19, -6, 14, 0, 28], [-220, 99, -21, 32, -20, -30, 30, -19, 14, 26, 7, 16, -11, -27], [-117, -49, -10, 16, 48, 38, -15, 52, -19, 5, 2, 58, -29, 4], [-464, 95, 24, -2, -55, 27, -41, -33, 3, 33, 20, -56, 30, 27], [44, -43, -50, 24, 0, 106, 25, 29, -24, -9, 18, -43, 1, -37], [92, -82, -103, -16, 46, 6, 47, 16, -10, 48, -49, 24, -5, -20], [199, -107, -63, 56, 43, 88, -64, 71, 27, -35, 32, -12, -32, 8], [254, 149, 34, 24, 62, -36, 68, 29, -72, 30, -65, 50, 5, -28], [296, 67, 28, 26, 38, -50, 71, 48, 12, -13, -23, 38, -6, -7], [-388, 59, -33, -14, 25, 23, -32, -27, 0, -12, 3, 17, 44, 26], [-370, -120, 49, 6, -72, 14, 2, -76, 13, -30, 44, -34, 28, 12], [154, -84, -116, -8, -145, 97, -60, -79, 97, -64, 53, -92, 48, 28], [388, 127, 63, 10, -64, -22, -72, -42, 13, 6, -4, 7, -46, -28], [-652, 111, -27, -12, 16, 31, -8, -51, 13, -51, 55, -35, 80, 35], [-130, -234, -163, -34, -22, 88, -22, -34, -5, 16, 96, -76, 2, -24], [-298, 229, -24, 18, -60, 50, -26, 21, 37, 86, -43, 20, -53, -1], [226, 281, -127, 26, 118, 12, 80, 32, -107, -26, -106, 37, 66, -60], [552, -319, -112, -20, -57, -45, -95, 7, 91, 29, 6, 96, -38, 67], [304, 76, 117, -68, 87, -66, 43, 49, -11, 44, -72, 62, -65, -29], [13, 147, 22, 46, 41, -6, 74, 53, -14, -25, -34, 50, -26, -62], [-102, 208, -25, 74, 158, -73, 82, 50, -106, 36, -50, 36, -68, -46], [423, 30, 31, -24, 55, -92, 50, 41, -19, -7, -12, 9, 48, 30], [-504, -290, -96, 30, -11, -152, 36, 15, -97, 9, -123, 99, -33, 3], [-1044, -121, -229, -8, 29, -40, 60, 44, -83, 123, -36, 29, -44, 12], [246, -143, -147, 48, 18, -38, -28, 101, -51, -9, 11, 73, -34, 64], [-708, -373, -81, -62, -107, 129, -16, -61, 104, -54, -59, 15, 56, -20], [310, -351, 17, 0, 289, 66, 99, 125, -52, 44, 20, 15, -15, -100], [30, 226, -154, 2, -155, 216, -133, 21, -31, -30, 44, -170, 1, 48], [-1086, -379, -179, -48, 125, -180, 8, -12, 17, 125, 18, 5, 48, -14], [174, 73, -6, -54, -114, 110, -120, -21, 119, 48, -19, 50, -29, 13], [-1354, 268, -78, -82, -188, 400, -86, -178, 101, -157, 150, -259, 165, 41], [-915, -479, 0, -26, 15, -110, 140, 13, -20, 97, -106, 92, -6, -36], [-56, -34, 123, 110, 2, -34, -174, 72, 60, 32, 128, -46, -156, -71], [-550, 480, 289, 60, 167, 30, 90, -37, -78, 29, 53, 31, -93, -23], [146, -52, 1, 76, -190, 59, -68, 38, 208, -124, 10, 96, 28, 72], [-831, 49, -72, 98, 103, 32, 96, 23, -38, 55, -36, 140, 2, 40], [884, 240, 129, -100, -9, -180, 138, -101, -86, -65, -169, 101, 31, -53], [-1089, -93, 3, -148, -17, -8, 129, -191, 135, -150, 5, -69, 118, 37], [278, 98, 2, -4, -10, -84, 179, -94, 69, 29, 99, 69, -12, 60], [456, 316, 217, -32, 201, 145, -59, 161, -102, -83, 52, 83, -118, -19], [-2010, -314, 82, -152, -21, 135, 110, 9, -50, -6, 67, -202, 60, -45], [632, 137, -41, 134, 19, 86, -241, 70, 122, -70, -69, 10, -224, -26], [-646, 1088, 195, 56, -85, -92, 139, -71, -14, -126, 58, -14, 151, 112], [270, 186, -144, 150, -45, -64, -17, -21, -57, 120, -10, 184, 45, -114], [-1474, 380, 156, 14, -110, -33, -202, 38, -31, -45, -46, -243, 47, 68], [-2566, -130, 127, -88, 61, -441, 148, 77, -169, 127, 33, 55, 57, 9], [100, 35, 143, -64, -97, 238, -11, -182, 56, -98, 31, -314, 206, 24], [-3729, -585, 125, -90, -144, -99, -215, 4, 80, -144, 46, -111, -94, 77], [-1632, 876, 220, -20, 176, -570, 8, 0, -220, -42, -86, 42, 36, 26], [-2612, 1265, 131, 166, 8, 138, -82, 56, 97, 126, -46, 99, -120, 46], [1198, 568, 190, 92, -46, 582, -123, 124, 85, 1, 227, -71, -40, -84], [-2518, 142, -363, 70, 182, 182, 61, 228, -55, 15, -65, -89, -68, -187], [-1121, 194, -180, 140, 200, -462, 185, -46, -221, 211, -242, -27, 5, -14], [-940, -205, -110, -18, -41, 16, -129, 215, 33, -46, 30, 145, -181, 58], [1092, 703, -158, 72, -25, 599, 5, 153, 55, -153, 120, -130, 226, -51], [-4720, 7, 161, 36, -330, 450, -106, -21, 158, -10, 149, -356, 157, -33], [-576, 334, -303, -20, -126, 345, -131, 48, 255, -38, 187, -206, -121, -40], [-2624, -377, 132, -330, -105, -190, -116, -256, 77, -27, 56, 7, 164, 17], [1918, 1211, 96, -206, 321, -21, 44, -94, -237, 134, -182, 106, 61, -42], [-1105, -1252, 203, -32, -109, -276, -216, 55, -93, 15, 162, 111, -256, -34], [1266, -703, 150, -94, 41, 8, -22, -192, -49, -95, -194, -273, -54, -71], [-868, 1273, 62, -42, 179, 8, 131, 301, -205, 176, 172, -109, -29, -44], [-3154, 488, -293, 72, 38, -303, -102, 30, 79, -119, -48, 209, 109, 41], [938, 1564, -76, -182, -297, 524, 173, -61, 203, -14, 68, 8, 309, 64], [-2040, 334, 849, 30, 30, -602, -157, -146, 23, -91, -319, -97, 60, 225], [-4692, 90, -29, 240, 280, -8, 251, 274, 13, 47, 79, 245, -346, -131], [-5026, 690, -279, 170, -64, 199, 0, 210, 27, -49, -74, 55, 101, 115], [634, 80, -560, 178, -63, 46, -17, 103, 199, 208, 58, 16, -225, -224], [2606, 341, -140, 316, 123, 308, -21, 278, -97, -37, -265, 231, -257, 102], [-654, 1480, -405, -212, 329, 434, 59, 145, 22, -190, -222, 150, 85, 72], [-4662, -816, -291, 8, -189, -673, -346, -45, -133, 71, -151, -163, -213, 1], [2855, -897, 568, -230, -70, 101, -378, 32, 121, -97, 327, -230, -84, 12], [-986, -680, -325, 16, 234, 272, -153, 144, -155, 5, -129, 177, -234, -7], [-2540, 522, 16, -130, -55, -413, 409, -367, -17, -5, -66, -99, 110, 37], [413, 792, -509, -450, -488, 428, 87, -280, -94, 49, 182, -317, 397, 142], [5569, 228, -561, -128, -244, 597, -166, -236, -16, -87, -23, -257, 78, 292], [-1670, 286, 399, -74, 290, 195, 194, -164, -91, -99, -138, 209, 257, 21], [614, -1092, -236, -248, -365, -529, -38, 15, 172, 402, -43, -246, -350, -65], [2568, -758, 527, 24, -113, -354, 104, -233, -256, 179, -135, 267, 13, -45], [3406, 501, -61, -56, -297, 278, -223, -183, -42, 74, -42, -293, -325, -34], [-764, -696, -362, -152, 227, -127, -256, -131, 144, -198, -327, 444, 18, 201], [2984, -1155, 0, 186, 198, 187, -154, 191, 47, 357, -253, 13, -378, -192], [-2694, 388, -512, 362, 705, -1232, 243, 667, -353, 278, -274, 718, -427, -150], [-410, -47, 561, -420, -503, 546, -17, -745, 380, -416, 290, -555, 479, 236], [3524, -704, -1006, -180, 413, 722, 402, 203, -291, 143, -215, 355, -183, -205], [-2142, -922, 79, -212, 209, -330, -343, 59, 96, 276, 6, -200, -1, 16], [9626, 1032, 263, -60, -3, 255, 336, 161, 221, -341, -7, 153, -31, 39], [-974, -1128, -344, 106, 519, 532, 70, 625, -252, 298, 117, 378, -170, -338], [10020, -344, 495, 310, 435, -221, 427, 415, -52, -323, -132, 599, -224, 83], [-2500, -1502, -1033, 530, 142, 46, -242, 542, -259, 162, -76, 216, -626, -226], [-4714, -2114, -1100, -76, 114, -114, -98, 270, -72, 138, 96, -192, -24, -308], [3844, -1395, -1071, -44, -650, 451, -394, -147, 355, -299, 313, 81, -72, 339], [5363, -176, 535, 40, -414, -251, -42, -326, 292, -105, 89, 165, 102, 268], [0, -2639, -147, 0, -131, 960, -56, 18, 61, 333, 268, -353, 258, 82], [-3692, 1045, -306, -62, -956, 328, -405, -176, -52, 39, 341, -550, 184, 261], [-3676, -470, -1184, 364, 114, 474, 280, 178, -206, 6, -392, 84, -272, -228], [2494, 1190, -13, 686, 385, -851, 299, 133, -452, 245, 48, -219, -86, -335], [2730, -1251, 205, -98, 198, -664, -50, -142, -177, -22, -118, -197, 318, 188], [-4264, -2112, -924, -166, 217, 444, 705, -337, -315, 78, -50, 450, 355, -212], [698, 1457, 1052, 58, 478, -436, 186, -165, -559, 56, 19, 66, -311, -99], [5524, -150, 748, -354, -322, -652, -326, -588, 303, -167, 192, -507, 341, -27], [3950, -1514, 425, 148, -73, 853, -42, -81, -71, -491, -137, -491, -21, 21], [7460, 2936, 39, -20, 555, 1140, 519, 295, -294, 84, -90, 446, 45, -56], [-3642, -1772, -532, 196, 15, -876, -538, -253, 121, -331, 135, -277, 315, 287], [1428, -566, 605, -384, 3, 546, -22, -415, 54, 33, 257, -549, 363, 201], [-1388, 3462, -150, 132, 88, 494, 160, 256, 170, 176, 82, 182, -250, 58], [729, -319, -298, 186, -245, -62, -662, 367, 104, -25, 222, -80, -136, -96], [1864, 833, -437, 394, 552, 430, 476, 414, -273, 444, -468, -21, -676, -338], [-1219, -631, -125, -46, -194, 281, -547, -46, 690, -614, 366, -395, 154, -23], [150, -4013, 135, 348, -467, -786, -506, 338, 109, -127, 96, 153, -478, 32], [-3610, -4005, -720, -110, -1304, -550, -417, -962, 720, -283, 101, -236, 58, 317], [3148, -1594, 603, -334, -620, 626, 83, -784, 350, -74, -403, -30, 307, 360], [9550, -1106, -698, 294, 807, -846, 170, 771, -249, 59, -255, 715, -429, -251], [-5138, 508, -1539, 254, -608, -142, 190, -478, 121, 106, -374, -144, 158, -332], [9458, 1792, -188, 120, -177, 1011, 238, -209, 173, 224, 377, -482, -16, -260], [-304, -1512, 825, -172, 903, 152, 695, -311, -332, -466, 268, 310, 609, -4], [7825, -349, 908, -110, -584, -1009, -254, -734, -59, -149, -81, -760, 298, 406], [-882, 1102, 1448, -132, 92, -68, 336, -108, 206, -532, 208, -30, 408, 286], [7278, -1890, 55, 126, -943, 1005, -331, 19, 450, 47, -144, 217, -312, 221], [-4856, -1066, -1500, 380, 308, 46, -342, 646, -514, 312, 46, 644, -650, -270], [-2835, 733, 418, 98, -457, 878, 324, -419, 354, -429, 804, -442, 542, 92], [-48, 1108, 1384, -328, -814, -160, -1162, 44, 356, 236, 398, -254, 96, 194], [13784, 1266, -1250, -276, -229, 1257, -218, 189, -133, -82, -87, -628, 102, -210], [-3861, -1893, -918, 280, 446, -1988, 225, 266, -633, 321, -868, 1038, -521, -352], [7314, 169, 267, -736, -1158, -340, 204, -879, -321, -551, -129, -857, 712, 458], [-5618, 409, -345, 180, 1174, -1713, 552, 223, -143, -167, -127, 347, 12, -599], [-2853, 2979, -946, -114, 218, -379, -314, 540, 83, 59, 19, -208, 176, -240], [1742, 2406, 1122, -192, 11, -839, 143, -215, -175, -77, 524, -887, 544, 55], [-114, 806, 1010, -560, 237, 727, 150, 111, -199, 194, -615, -154, 12, -162], [9260, -1786, -979, -156, -334, 773, 204, -248, 177, 1005, 46, -827, 255, -93], [-5320, 1637, 601, -772, 77, -256, -312, -130, -129, -201, -286, -467, 466, 248], [2590, 1478, -2520, -574, 166, -47, 516, -90, -205, 20, -30, -260, 412, -38], [10596, -3114, 575, -430, -733, 1647, -356, -797, 322, 132, -17, 112, 724, 240], [1472, -1450, -526, 164, -411, 1027, -440, 585, 453, 348, 655, -258, -388, 248], [2386, -2910, 114, 336, -235, -1355, 320, -775, -149, -318, 545, -114, 540, 428], [330, -1083, -1002, 278, -707, -1269, -434, 226, -65, -408, 148, 278, 369, 894], [-6214, 1064, -263, -226, -362, 144, 476, -252, 147, -524, 282, -466, -46, 222], [2330, 5792, -692, 152, 380, 238, 382, 802, 100, 824, -80, 538, -612, -612], [-10486, -1937, 463, 590, -186, 268, 104, -438, -601, -540, -162, 219, -244, -196], [3050, -5942, -196, -106, -245, -674, -572, 305, 449, 229, -955, 51, -335, 407], [-796, 2859, 1662, 640, 240, 725, 358, -531, -36, -394, -137, -292, 393, 145], [1056, 2316, 523, 574, 938, 706, 268, 114, -204, -746, 40, 16, -258, -881], [5450, -632, -90, -216, 559, -751, -69, -387, -167, 255, -304, -633, 480, -273], [-4512, 2457, -961, 26, 190, 1242, -934, 130, -311, 390, 84, -25, -12, -426], [-8150, 3001, 1861, -544, -848, 704, -130, -267, 308, 148, 501, -848, 133, 31], [101, -4089, 820, -792, -1004, 702, 301, -976, 241, 185, -172, -658, 29, 22], [-10532, 4149, 405, -282, -920, 920, -468, -132, 853, -154, 510, 575, -360, 480], [-7858, -3696, -455, -740, -735, -550, -673, -673, 752, -2, -464, 244, -581, 748], [4294, 684, -688, 140, -500, 1818, 576, -44, 304, -334, -372, -66, 746, -194], [-4796, -2488, -952, 76, 770, -558, 568, 698, -620, 886, -1346, 1698, -914, 382], [5968, 2788, 786, 532, 80, -1928, -548, 828, -532, 700, -400, 464, -1188, -298], [1146, 2742, 540, -360, -1094, 1406, 379, -794, 345, -141, 191, -585, 290, 480], [-2010, -1762, -1024, -512, -1590, -782, -758, -246, 1172, -702, 762, -1644, 370, 504], [3078, -4424, 866, 346, 712, -445, 738, -64, 459, 337, -436, 1195, -47, -208], [-14716, 2012, 1023, -184, 1495, -1551, 1275, 35, -1166, 171, -1000, 713, 386, -527], [-6518, 1305, -105, -208, 1128, 465, -706, 1497, 7, 69, -135, 767, -426, -65], [12810, -2607, 841, -44, 527, -66, -26, 1054, 259, -261, -596, 499, -470, 440], [11770, -2772, -80, -952, -55, 109, -617, -129, -613, -199, 334, -1099, -98, 323], [3176, -1078, -1567, 130, -61, 491, 343, 497, -658, -29, -298, 629, -460, 487], [8928, -370, 166, 564, 1777, -797, 1441, 601, -1301, 399, -732, 327, 430, -1003], [-2105, 2348, -1103, 744, -542, 1145, -796, -206, 530, -755, 1599, -769, -190, -422], [16462, 893, 1671, 104, -215, 1874, -336, -728, 345, -753, 884, -153, -164, -470], [-15682, 2422, 240, 726, 479, -648, -186, 547, -754, 346, -169, 978, -144, 56], [12302, -2562, -1264, 8, 352, -516, 1076, -618, -890, 848, -416, -168, 704, -362], [-12423, -1369, -1363, -714, -756, 1309, 13, 260, 682, 164, 752, -259, 468, 763], [232, -3822, 759, 660, -677, -426, -841, 459, 720, -348, -490, -196, -151, 328], [320, -3907, 159, -204, 244, -110, 503, 27, -1121, 388, -190, -322, -258, -179], [-3701, -2547, -1717, 562, 1043, -202, 633, 637, -1029, 96, -421, 1385, 506, -387], [7874, 5922, -221, 154, -415, -2167, 705, -927, -558, 193, -530, 913, -132, -523], [-24640, 657, 111, 84, 308, 501, -558, -1, 385, -419, 299, -139, -552, 141], [-9788, -6750, -2212, 570, -343, -194, 667, 175, -313, 442, 288, 60, 227, 44], [-3574, 1070, 919, -904, 403, 544, 775, -533, 740, -618, -452, -518, 949, -226], [7294, 216, 667, -464, -297, -452, -650, -803, -372, -291, -137, -1283, 613, 163], [66, -3774, 1762, 56, -966, -24, -1452, -624, 410, 648, 230, -996, -388, 428], [12928, 1331, -402, 1118, 762, 66, 731, 650, -300, 153, -441, -62, -910, -1029], [2276, -2055, -1235, -478, 451, 440, -395, 522, 12, -62, -183, 850, 106, -82], [-8509, 2756, 142, -1782, -1664, -553, -495, -1304, 681, 140, -398, 522, 818, 625], [-15903, 5673, 1703, -410, -416, 533, 287, -1120, 952, -1534, 794, -459, 720, 425], [-5884, 6351, 323, 268, 629, -306, 468, 68, -809, 129, -98, -341, 1024, 480], [-19984, -1482, 1025, -656, -909, -1690, 332, -1271, 394, -779, 235, -245, 469, 735], [-8466, -3836, 1435, -96, 1350, -1041, -80, 698, -362, 400, -1174, 1536, 184, -268], [3164, 4427, 722, -518, 2261, 1076, 309, 441, -1033, -266, -1062, 481, 421, -206], [18094, 6796, -1326, -232, -560, 228, -164, -16, -358, -264, 654, -1428, 474, 444], [4444, 7567, 1056, 342, -1699, 1957, -1690, -354, 241, -161, 1100, -1125, -68, 252], [13386, -6036, 1051, 1368, -411, -1868, -276, -63, 274, -25, 17, 1177, -377, -405], [-16990, 1781, 345, 776, -505, -1210, -353, -341, 654, 798, -546, 1045, -861, -518], [2458, -1395, 400, 630, -551, 2257, 566, -254, 92, 50, 344, -1292, 303, -289], [23772, -5108, -183, 1038, -81, 1085, -1303, 1055, 412, 137, 1742, -1017, -214, -439], [-23636, -1743, -1059, -76, -359, 1341, 1218, -1498, -666, 806, 306, -814, 1489, -428], [-19718, -1076, -980, 1024, 200, -1128, -1241, 478, -375, -701, 375, 871, 420, 238], [3532, -8, 1381, -670, -362, 560, -613, 684, -292, 1382, -731, -542, -1379, -574], [-9374, 4554, 1232, 256, 1350, -2320, 1092, 908, -632, 512, -960, 2408, -1134, -732], [13168, -3732, 749, -694, -998, -708, -608, -1318, 435, 256, 80, 414, 258, 274], [18668, -8555, 1027, -1014, -1326, -800, 882, -710, -129, -1310, 4, -125, 368, 870], [1180, 1719, -2577, -1212, -634, -1178, 687, -77, -637, -550, -606, -160, 518, 657], [4796, -1142, 771, -558, -155, -1115, 492, -469, -236, 1618, -763, 728, -616, -976], [12744, -6488, -132, -516, -680, 1170, -344, -1008, -18, 564, -164, -624, 812, 484], [13498, 1102, -23, 804, 323, -191, 100, -91, 417, 1193, 323, 227, 99, -101], [1660, 8170, 4141, -2, 533, -875, -284, -575, -74, -262, 13, -690, 242, -144], [-15408, 8697, 3647, -852, 434, -740, 1293, -1199, -709, -448, -610, 174, 1016, 205], [6538, 4061, 833, -1042, -1360, 3231, -945, -891, 1854, -794, 810, -1892, 908, 183], [-4554, 2558, -3010, -1002, -2230, 4425, -1304, -616, 1805, -866, -268, -276, -452, 426], [-1914, 3830, -2676, -1072, -407, -723, 120, -377, -377, 756, -453, 136, 44, -670], [17588, -796, 1076, 448, -846, 2014, 574, -62, 344, -1416, 358, -368, 344, -292], [21356, 1267, -655, -1342, -2099, 1697, -46, -1266, 1520, 636, 2060, -1298, 497, -54], [3148, 5040, 2076, 0, -2389, -975, -2061, -515, 1191, 1021, 482, -987, 8, 779], [-18188, 1548, -833, 152, -624, -888, -1519, 1336, 675, 163, 615, 885, -622, 557], [-10240, 7628, -548, -536, -405, 1501, 456, 7, -91, -418, -187, -880, 426, 52], [23844, -9028, 693, 712, 1407, -1178, 1030, 543, -285, 587, -991, 847, 5, -806], [-2538, 9218, -3434, -546, -969, 226, 402, -1179, 875, -409, -313, -1059, 597, 149], [-2756, -5401, 3103, -1148, -103, -3376, -114, -1312, 537, -501, -852, -279, 1332, 1702], [3130, 9413, -617, -84, 607, -484, 141, 583, -202, 456, 260, 47, -89, -684], [8490, -1202, -1472, -1384, -430, 1970, -312, -1572, 1462, -460, -348, 356, 314, 680], [-14864, 4483, -2654, 70, -1240, 269, -1314, 663, 685, -277, 1099, 707, -574, -858], [-8356, 1198, -375, 1164, 639, 1854, -444, 53, 407, 617, 469, -491, 499, -176], [8156, 4314, 795, 1006, 2070, -622, 1211, 1286, -1480, 492, -1189, 2072, -1331, -754], [4008, -7785, -1087, -214, -1377, 1925, -420, -899, 1302, -578, 675, -1763, 180, 248], [-12116, 9588, -245, 686, 1360, -734, 1182, 478, -1425, 1278, -46, 350, 240, -240], [12606, -5946, -2596, -866, 580, 197, 414, 174, -1159, -233, -1034, 585, -807, -1102], [-10118, 7034, 751, -968, -1999, -456, -2377, -1061, 1510, 1450, 644, -1264, -105, 260], [12474, 790, 1849, 28, -1309, -1227, -1437, -1243, 1224, 863, 136, 1413, -1366, 873], [8380, -8166, -4471, -170, 1014, 924, -1995, 924, -173, 1097, -387, -295, -376, -691], [-12161, 6692, 1481, 226, -1596, 1032, -1419, -44, 558, 1123, 1102, -1711, -525, 254], [-22834, -4578, -1525, 1172, 2006, -19, -622, 512, -56, -548, 638, 1216, -412, -1066], [1628, 4804, -268, -690, 353, 1184, -776, 51, 949, -623, -339, -2331, 131, 185], [14160, 1232, -2384, -70, 1215, 266, 1783, 781, -1417, 88, 22, 344, 431, -1546], [-15426, 6042, 1076, -608, -1510, -1604, 912, 198, 202, -892, -118, -282, 496, -86], [-4244, 9336, -1642, -1132, -279, -1469, 1084, -13, -341, 644, 897, 1142, -510, -202], [6123, 2938, 3080, 324, -940, -154, -309, -778, 735, -1935, 2004, -229, 617, 596], [-2820, 3826, 2869, 566, -1916, 406, -1299, -1732, 792, -2048, 979, -1532, 783, 1066], [9188, -9506, 3706, 622, 201, -508, 820, 97, -621, -123, -369, -951, -11, -259], [10560, 6960, 538, -1984, -794, -496, 906, -968, 388, 280, 200, -282, 546, 0], [10192, -704, 1740, 712, -650, 1200, -456, 234, 1072, 944, 920, 1156, 210, -784], [13438, -3540, 2024, -532, -507, -984, 40, -2215, 903, -999, 823, 923, 2197, 1799], [2822, 4041, -1621, 512, -1959, 944, 832, -900, 95, -1037, 1424, -989, 1128, 1078], [-18368, 4337, 1750, -666, -1229, -1400, 346, -396, 1017, -263, 130, -727, 482, -885], [-18216, -5148, 5976, 1112, -200, -928, 628, 756, 306, -1252, 1514, 764, -950, -30], [-24738, 5130, 3132, -242, 959, -754, -703, 1181, 25, -428, -510, 1686, -1091, -660], [-29728, -10925, 1609, -300, -1311, -1271, -72, -1158, 974, -464, 936, 310, 437, -318], [12186, 2611, -1229, 1000, 2296, -889, 592, 1203, -1289, 365, -1543, -505, -766, -573], [-10589, -9579, -847, -604, -1311, 4476, 66, -263, 881, -339, 1072, -1084, 778, -304], [-6354, -2252, 3249, -1008, 861, -388, 52, -1279, 1082, -2269, -1079, -1499, 1083, 261], [-41256, 4945, 1053, -1648, -1041, 2832, -681, -643, 748, -1036, 946, -2255, 1037, 1850], [13032, -7785, -3819, -1744, 1215, 2438, -1151, 1371, -292, -152, 1174, -903, 887, -196], [14350, -7565, 1046, 394, 381, -2151, 880, -596, -815, 1296, -552, 1014, -415, -568], [-3956, -1764, -869, 552, 712, -1135, -1354, 2984, -823, 995, 8, 171, -2399, -1469], [34894, -2558, -3382, 442, 459, -2686, -959, 379, -1273, 1044, -1716, 2468, -851, 474], [9124, -7006, 100, 1272, 3333, -2461, 2045, 1243, -2209, -855, -1942, 2911, -698, 479], [-28532, -8282, -16, 826, -165, 1020, -652, -1163, -793, 93, 1031, -2013, -201, 479], [-26972, -9423, -2334, 818, 1011, 1003, -86, 746, 125, -183, 4, -3, -608, 464], [19446, 1857, -1339, -576, -1292, 2631, 810, 1269, -57, -755, 933, 1227, -10, -501], [-14690, 5146, 66, -836, -866, -1118, -334, -1030, 42, 946, -754, -252, 310, 440], [14016, -4463, -2094, 88, 1158, 1353, 1968, 677, -80, 606, -287, 2312, 597, -189], [-26246, -3050, -498, -314, 309, 2155, -163, -833, -51, -435, -374, 2549, 1440, 581], [1950, -2248, 1673, -2018, -1026, 3602, -385, 92, -219, -563, 1901, 575, 912, 847], [10706, -8372, -5254, -12, -1227, 3841, -757, -891, 115, -193, -648, 1577, -274, 1385], [-24574, 15434, 284, -1114, 1952, 454, -132, -116, 57, 415, -34, 1113, -11, -525], [17392, -727, 797, 106, 1169, 572, 813, 1826, 742, 260, 473, 1410, -10, 592], [-8734, 2764, 2526, -20, -3880, 1710, -1876, -1462, 3590, -1364, 912, -1466, 988, 1510], [-41370, 3417, 2397, -746, 2125, -243, 994, -1195, -554, -970, 283, 851, 746, -630], [14556, 11110, -2398, -540, -2830, 986, -1676, -2350, 2894, -562, 722, 640, 294, 1150], [-11852, -1908, 4259, 2762, 2155, -1105, -1528, 3215, -204, 1188, -1563, 1490, -2036, -738], [-39300, 16167, 561, -770, 2285, 1061, 1092, 1557, -818, 982, -1693, -1049, -466, -88], [-27322, -2686, -2696, -1250, -2571, 3830, -277, -2591, 895, -302, 2088, -1970, 2709, 422], [-37198, 3473, -5109, -418, -1057, 1981, -1122, 2231, 646, -704, 285, -1375, -720, -1116], [-25538, -4463, 490, 376, 3460, -930, 1270, 2916, -1518, 2776, -1486, 895, -954, -448], [-58020, 15357, 315, 1152, -223, 1751, 1204, 1010, -950, 994, 1212, 678, -1141, -6], [21153, 7202, 3600, 774, 481, 4266, 551, 633, 656, -1116, 2325, -658, 258, -631], [648, -9264, -2168, 66, -743, 1823, 1483, -2189, 275, 353, 338, 1519, 2252, 243], [10614, -4844, -1979, -2310, -1440, 2540, -456, -2058, 1527, -2122, 2428, -3112, 1184, 498], [-19116, 7263, -629, -146, 423, -1145, 1292, -545, -72, 624, -1471, -1213, 828, -722], [-22716, 2342, 2269, -566, -822, 2368, 2941, -3282, 356, -1458, 573, -1062, 2077, -476], [-27196, 5465, -1509, 1382, -1356, -3232, 106, 1986, -477, 1206, 768, 201, -2370, -630], [6765, -7273, -2034, 790, 1771, -596, -66, -443, -1062, 1501, -1276, -806, 624, -1504], [-30742, 6262, -1952, 1168, 1777, 673, 1713, 1521, -3203, 663, -330, 707, -732, 183], [7894, 6512, 4400, -66, 3477, -6268, 504, 2259, -2129, 629, -2941, 3181, -1287, 495], [25924, -1881, -5521, -548, 302, 794, 2025, -373, -443, 206, -1076, 1032, 960, 1361], [-68916, -3496, 141, 262, -1316, 1278, -611, 190, 87, 59, 1271, -2183, 1098, -881], [27466, -6932, -25, 980, 2643, -1885, 366, 1403, -1061, 611, 1243, 1809, -231, -1477], [9522, 4770, 4562, -450, 1698, -3861, 1132, 2528, 437, -1479, -146, 2447, -1467, -84], [-23224, -9199, 382, 830, 1249, -2132, -1126, -304, 89, -773, -354, -151, 798, 1067], [-52214, -1173, 987, 1804, 1470, -340, 2802, -1011, 856, -106, 349, 2382, -559, -975], [-36958, 12127, -1662, 1004, 4691, 979, 4317, 2740, -2602, 1167, -611, 3331, 3, -776], [-436, -6492, 129, 1802, 42, -4040, -1476, -238, 936, 284, 1240, -262, 1244, -529], [1208, 422, -3158, -992, -4319, 5413, 93, -1533, 2465, -961, -234, -2147, 1744, 801], [-58824, -5258, 193, -778, 2978, 216, 3157, 456, -2623, 867, -2387, 995, 1162, -1133], [-14704, 10125, 1130, -1990, 739, 4687, -666, -1630, 1469, -1871, 1332, -2887, 416, 144], [-36595, -8323, 1776, -1126, -597, -276, 2586, -981, -2040, 1305, -1836, 46, -280, -596], [-27114, 3629, -263, 888, -2708, 1060, -2302, -2119, -324, -54, 345, -2294, 899, 211], [29680, -10482, -2266, -2596, -1760, -3364, -832, -128, 946, 672, -2504, 2942, -64, 936], [43970, -1808, -4386, 196, -1504, 4128, 1102, 126, 1690, -1524, 2192, -1558, 236, -1278], [-21886, -1112, -2384, -1566, 3691, -880, 1196, 2509, -1646, 1846, 807, 214, 1996, -1058], [42286, 2370, -1842, 260, -3090, 1488, -18, -1422, 1454, 340, 1758, 930, 1132, 362], [-11550, 8534, -2798, -1884, -755, 4700, 3148, 1559, -5, 1399, -491, -1435, -7, -843], [-44420, 1112, -462, 688, 66, 4344, -1238, -28, -1614, -154, 324, -640, 32, -714], [-26620, -7283, 3165, 770, -756, -1555, 821, -1505, -1304, 370, -692, 1502, 278, 709], [37120, -13534, -3408, -484, 3106, -2698, -370, 1834, -2198, 358, 676, 864, -484, -450], [-22702, 6712, -1830, -2716, -2416, 3320, 850, -3590, 2892, -1234, -154, -32, 2768, 808], [5794, -6114, -1487, -1064, -4212, 1524, -847, -1568, 467, -1285, -1631, -1953, 784, 1203], [-32206, 3979, 2693, -928, -799, -2085, 1394, -1662, 410, -1547, -382, 2493, -74, 474], [10324, -7630, -2204, 1184, 3018, 810, 2594, 50, -2342, -916, -154, -2434, 2288, -1222], [29378, -354, 567, 1792, 843, 1835, -2124, 91, 1159, -1131, 1357, 1529, -2487, -1571], [18042, 3230, 3960, 614, 3075, -764, -470, 3175, -879, 1079, -1031, -597, -1657, -2021], [16338, 10222, -2111, 1472, 4465, -292, 87, 4049, -2092, -456, 918, 770, -517, -1398], [37452, -10420, -2217, 700, -56, -3689, 2690, 302, -1839, 497, -182, 1879, -15, 177], [-47042, 12668, 1161, 330, -706, 1096, -1676, 596, 2341, -2418, 1114, 676, -724, 2020], [57395, -3879, 2582, 1230, 4371, -1470, 1980, 2835, 310, 855, -2792, 3520, -3494, -1836], [716, 3946, -989, -672, 1762, 5213, -1999, -548, 1307, -28, 1123, -1272, 341, 26], [-5510, -16966, 5572, -1118, -1197, -2542, -1051, -1541, 1925, 532, -1168, 496, 143, -728], [6392, -3934, 128, -168, 518, 5698, -148, -982, 1706, -2540, 2176, 726, -602, 796], [3843, -7031, -1156, 1034, 3936, 1313, 1644, 1552, -2995, 1815, -603, -676, -2196, -518], [-39660, -1609, 1057, -754, -4820, 1654, -1352, 372, 1425, -2608, -198, -2689, 946, 758], [25398, -2248, 2299, -248, -2909, -3167, -1196, 1847, 151, 423, 1117, -135, -2941, 211], [-22134, 5741, 667, 2022, 4052, -486, 3510, 2400, -1883, 810, 366, 19, -2752, -2158], [-3828, 2525, 2703, -466, 1255, -3763, 1270, -1211, 568, 500, 537, -2019, 1852, -30], [44642, -9001, -1040, 668, 2065, -2196, 2897, 2750, -1847, -475, -1595, 3101, -2207, 394], [7756, 3170, 1098, 2164, -4776, 328, -3572, -2340, 2930, 48, 656, -3790, 1924, 2508], [-44408, 1168, 1454, -1648, -2581, -4863, -1210, -3043, 1805, 348, -1263, 1328, 252, 1640], [35696, 8982, -68, -1028, 1629, -2621, 580, -2263, 503, -358, 2047, -2516, 2698, -172], [-6036, 7716, -2407, 2782, 4079, -1030, 2358, 1157, -2096, -87, -705, 795, -1569, -1877], [31192, -13793, -3278, 360, 354, 4652, -2062, 1854, -16, -322, -60, -87, -2298, -1408], [-41142, 9526, -1036, -1374, -5379, -1920, -262, -3993, 1534, -2236, -9, -1966, 1872, 3276], [58056, -184, -2886, -824, 645, 2896, 2309, 161, -1242, 185, 1594, -1781, 356, -2555], [-38278, 6250, 3657, 1526, 2622, -570, 1474, 608, -4897, -1554, -1420, -1338, 266, -1302], [9772, -2944, -1800, 100, 1258, -6714, 2492, -2066, -2056, 3072, -2604, -104, 650, 942], [35686, -12198, 3758, 2220, 3368, -1586, 4342, 3002, -1728, -2468, -278, 4284, -474, -758], [15844, -7384, -5135, 12, -4744, -3143, -2456, -192, 2069, 305, 138, -2767, 897, 1815], [12818, 6514, 5011, -2206, 1177, -2757, 380, -1243, -146, 496, 2717, -4380, 454, -292], [-9354, -7504, 5378, 182, -4508, 371, -1406, -3616, 1137, -1991, 2572, -1997, 1393, 2038], [-54582, 1837, 2184, 1544, -375, -4566, 1703, 40, -737, 1557, -3555, 1393, -1543, -520], [23442, -8575, -160, 230, 3900, -5395, 1910, -369, -3219, 1369, -1407, 1443, 542, 356], [42712, -8373, -3854, -556, 5022, -5713, 1532, 3095, -4634, 1620, -2447, 2374, -153, -1357], [-30236, 9111, 2225, 250, -1713, -2325, -3580, -647, 1654, -2564, -285, 1555, -598, 1214], [-57243, 3269, 4963, -1276, 375, -4950, -1590, -529, 487, 673, 348, 588, 164, 638], [29384, -17342, -4487, 296, 2266, 235, 1625, 2660, -2807, 964, -1113, 528, -1251, 592], [-12174, 5585, 415, -1946, -786, -1828, -1680, 1106, 155, -396, 942, -4767, -204, 352], [22414, -23791, 2591, -294, 3322, -7594, 1794, 1636, -697, 946, -1880, 3089, -1220, -1528], [-22450, 2106, -2576, -2856, -2398, -490, -1442, -1012, 962, 194, -10, -1382, -1310, 1586], [4524, -7698, -7773, 1724, 688, 5319, 2314, 3036, -1941, 2383, -2540, 1541, -259, -1573], [14488, -8399, 4233, -22, 258, -7553, 4257, -2247, -302, 1356, 2338, 2372, 896, -1395], [-21650, 15952, 8612, -1468, -2279, -8399, -2382, -2231, -193, 426, -1613, 2848, 1378, 2108], [-34210, 10384, -6640, 3222, -514, -2096, -630, 1488, -1091, 2205, -1884, 2691, -1301, -2509], [-3102, 4516, 1823, -152, -1825, -4163, -2350, -1941, -557, -535, 691, -1389, 419, 2477], [22284, -5362, 1019, -686, -790, -1774, 1074, -5350, 35, 958, -572, 392, 3410, 2256], [-27349, 7499, -3303, 2880, 5090, 893, 4515, 88, -990, 2058, -2800, 3189, -1024, -2381], [30668, -17890, 2163, 1590, 157, -785, -1243, 871, -822, 1247, 1082, 897, -3858, -1917], [6192, -6752, -4807, 592, 5084, -1277, 201, 7092, -1699, 1740, -601, 2104, -2721, -2720], [62515, 4449, 1484, -210, -3381, 2740, -864, -2419, 126, 2353, 1350, -1280, -22, 1556], [-5363, -2443, 994, 1088, 5646, 4440, 643, 1848, -1537, 3019, -1810, 532, -1391, -2128], [-19534, -9402, -6273, 2020, 2299, 1131, 900, 1633, -1187, -2081, -123, 1549, -797, -985], [30469, -14077, -1009, -646, 2771, -838, 3285, -553, -2905, 396, 947, -3555, 2262, -3243], [37286, -6541, 4182, -474, -795, -2382, -1465, -451, 2271, -980, 2842, -1097, 2391, 1786], [32845, 6965, -4672, -2734, -3866, -9, 1812, -300, -1053, 135, 671, -1766, 2612, 3086], [-24658, -8294, -678, -426, -3915, 4308, 3519, -929, -711, -2766, -686, -1016, 1297, 530], [46470, 4666, -238, -576, -1131, 135, 2628, -2617, 1747, -1806, 4135, -296, 2526, -542], [-15986, -12057, -4063, 468, -895, 6144, -1017, 809, -10, -748, 3056, -5371, -323, -600], [44976, 5232, 7399, -502, 1190, -4116, -82, 1110, -2597, 894, 2028, -1294, -1622, -1514], [20499, -1319, 3347, 1058, -504, -4292, -697, -3154, -2382, -381, -900, -3566, 1951, 552], [-12, -4858, 534, 152, 827, 6005, -3904, 1209, 687, -1994, 311, -1148, -1260, 444], [-18090, 14310, 522, -64, 2021, 2829, -1811, -167, 1417, -2197, -2826, 435, 1084, 1973], [18764, -161, 5022, 530, 1045, -9193, -2627, 1855, -1891, -2181, 14, 602, -290, 1973], [35017, 21482, -2968, 1098, -1012, -3381, -605, 2412, -783, 694, -1182, -430, -3872, 993], [-42608, -619, -4093, 2340, 4435, 3556, -2992, 5092, -2815, 2013, -1834, 619, -2722, -632], [-35306, 9574, 3425, -1854, 2854, 192, 2083, -3608, -2505, -2201, -1187, -93, 2718, -81], [-11076, -5686, 3234, 2308, -1454, 3796, -464, -1180, -342, 1316, 782, -1996, -340, -944], [-31076, 12028, -3673, 3074, -3208, -748, -844, -1068, -303, 1044, 1186, 1018, -270, 114], [34212, -16894, 3848, 3424, 3386, -2200, -1668, 900, 162, 1254, 2304, 1582, -224, -2934], [19555, 11597, -3281, 534, -2456, 1872, 795, 188, 1352, 447, -1550, -160, 989, -122], [-37142, -5968, -4381, 1660, 4010, 1583, 2912, 1002, -2812, -2298, 926, 1726, 2618, -638], [-844, -10102, 5866, 1706, -2783, -8122, -1255, -1505, 1147, 528, -2166, 338, -4547, -1198], [96159, -8139, 6142, 982, -3295, 6636, -3596, -693, 1666, 2619, 1576, -2038, -1484, 1918], [-34618, -21831, 2309, -594, -2602, 5308, -998, -2468, 2677, -1796, 1784, -3305, 4606, 2694], [82872, -21135, 628, -2346, 1261, -4461, 1236, -2036, -140, 4512, -2838, 684, 1347, -945], [-9938, 4434, -2854, 738, 6598, 4150, 4746, 4064, -4077, -241, -840, 859, 909, 897], [-52000, 10041, 6747, -334, -3157, -1206, -4111, 1692, 2734, -1744, 2891, 750, -1462, -300], [1522, 3304, 2331, -452, 3133, 5085, 1764, 1265, -3097, 2967, -2829, 1533, -2109, -1169], [2714, -10323, 2801, -2632, -5331, -2960, -1790, -4720, 6123, -1857, 396, -53, 1564, 2294], [39164, 6301, -5747, 4334, 6046, 689, 1713, 3625, -416, -1294, 2814, 602, -878, -1463], [18130, 11436, -3484, -2786, -5571, 2558, 1146, -947, -239, 3679, 1551, -2307, 2231, 149], [12793, 4032, -2202, 2708, -4226, 8778, 1269, 456, 1669, -475, 1134, -991, 2057, 1366], [-37674, 2818, 5888, -2394, -987, 1422, 3174, -3009, 2986, -2186, 1143, -220, 2138, 2122], [12336, -590, 7045, 34, 1495, -899, 3391, 97, 748, -1615, 1730, 1143, 1698, 1699], [40629, -155, -13610, -2212, -1042, 2618, 2095, -2272, -861, -1683, 1678, -1870, 4581, 1276], [-13807, 8286, 471, -942, 3208, -3086, 2249, 708, -866, -2271, -624, 2497, 2731, 2894], [38684, 17371, -9943, 904, -1378, 8111, -486, -2429, 3371, 589, 1591, -667, -1262, -1041], [-11446, 8940, 1542, 2932, 8386, 4178, -1538, 7362, -3496, 3506, -1358, 3854, -4326, -4962], [-44284, 8389, 4814, 4652, 8566, -3408, 1019, 4187, -5844, -1603, -2594, 5963, -1815, -3097], [49346, 18504, 4326, 980, 2467, -9363, -1514, 1427, -2227, 868, -2263, 848, -3812, 1128], [-26030, 18445, 8951, -2072, -130, 5538, 472, -1447, 989, -323, 927, -6685, 584, 594], [-34134, 11960, 7245, -1424, -3653, -2875, -6301, -2855, 1694, 1019, 204, -2689, -46, 3079], [9502, -9652, 5244, -1002, -6229, -884, -4231, -2865, 1511, -4816, 2744, -1462, 1253, 2646], [24808, -20322, 5638, 1594, 2584, -9322, 3916, 1650, -2655, 2505, -308, 1257, -409, -295], [-36274, 1498, -3564, -2148, 4922, -3136, 2562, 1852, -2208, 2174, -2204, 6950, -5400, -1446], [-12144, 28717, 3569, -3974, 12, 6524, -2382, -2286, 1263, -338, 1434, -3511, 2008, 1196], [492, -3761, 5099, 3924, -2696, -2529, -3520, -1517, 1141, 309, 517, 1123, -6918, -159], [-45064, -1580, 1771, -1278, -3423, 969, -845, -831, 1334, -6451, 338, -3565, 1156, 3327], [25076, 16635, -1820, -2778, 4491, 2523, -1462, -932, 2214, -1406, -2096, -3098, 2501, 2539], [-9116, 10112, -949, -446, -1342, -1186, -1914, -286, 1807, -2100, 1918, -2938, 2148, -1060], [13666, 11288, 893, -770, 3752, 2949, -1638, 1684, 508, -2150, -1568, -1322, 2114, 796]]
